from pointwise import GlyphClient
from pointwise.glyphapi import *

def echo(text):
    print "Script:", text 

# port 0 is special as it launches a Glyph batch process locally

with GlyphClient(port=0, callback=echo) as glf:

# port 2807 is the default Glyph Server port (when running active server
# in Pointwise GUI)

#with GlyphClient(port=2807, callback=echo) as glf:

    pw = glf.get_glyphapi()

    pw.Connector.setCalculateDimensionMethod("Spacing")
    pw.Connector.setCalculateDimensionSpacing(.3)

    # create a loop of connectors from a cyclic list of points
    points = [(0, 0, 0), (10, 0, 0), (10, 10, 0), (0, 10, 0)]
    cons = []
    with pw.Application.begin("Create") as creator:
        for p1, p2 in zip(points, points[1:]+points[:1]):
            seg = pw.SegmentSpline()
            seg.addPoint(p1)
            seg.addPoint(p2)
            con = pw.Connector()
            con.addSegment(seg)
            con.calculateDimension() 
            cons.append(con)

    # create an unstructured domain from the connectors
    with pw.Application.begin("Create") as creator:
        edge = pw.Edge.createFromConnectors(cons)
        dom = pw.DomainUnstructured()
        dom.addEdge(edge)

    print "Domain:", dom.getName(), "cells:", dom.getCellCount()



from pointwise import GlyphClient
from pointwise.glyphapi import *
import dbutil as db
import conutil as cn
import apputil as ap
import testutil

import os, sys, unittest

class TestUnsDomain(testutil.TestBase):
    def testSPR16159(self):
        pw = self.pw
        ap.loadFile(pw, "SPR16159.pw", True)
        dom = pw.GridEntity.getByName("dom-9")
        dom.initialize()

        self.assertEqual(dom.getTRexFullLayerCount(), 6)
        self.assertEqual(dom.getTRexTotalLayerCount(), 10)
        self.assertInTol(dom.getTRexCellCount(), 970, "5%")

    def testSPR12450(self):
        pw = self.pw
        ap.loadDB(pw, "SPR12450.igs", True)
        pw.Connector.setCalculateDimensionMethod("Spacing")
        pw.Connector.setCalculateDimensionSpacing(0.01)

        models = pw.Database.getAll(type="pw::Model")
        model = pw.Model.assemble(models)

        quilts = pw.Database.getAll(type="pw::Quilt")
        quilts = pw.Quilt.assemble(quilts, maximumAngle=45.0)

        self.assertEqual(len(quilts), 8)

        doms = pw.DomainUnstructured.createOnDatabase(quilts,
                parametricConnectors="Aligned")

        self.assertEqual(len(quilts), len(doms))

    def testCreate(self):
        pw = self.pw
        line = db.makeCurve(pw, [(1, 1, 0), (1, 2, 0)])
        self.assertGlyphType(line, "pw::Curve")

if __name__ == '__main__':
    unittest.main()



from pointwise import GlyphClient
from pointwise.glyphapi import *

import os, sys, unittest

def dump(line):
    print(line)

class TestBase(unittest.TestCase):
    port_ = 0
    auth_ = None
    host_ = 'localhost'

    @classmethod
    def setUpClass(cls):
        cls.glf = GlyphClient(port=TestBase.port_, auth=TestBase.auth_, \
                host=TestBase.host_, callback=dump, \
                prog=['/opt/builds/tapestry_nightly/release/pointwise', '-b'])
        cls.pw = cls.glf.get_glyphapi()

    @classmethod
    def tearDownClass(cls):
        cls.glf.close()

    def assertGlyphType(self, obj, gtype):
        self.assertTrue(isinstance(obj, GlyphObj))
        self.assertEqual(obj.glyphType, gtype)

    def assertEqual(self, v1, v2):
        if not isinstance(v1, (list, tuple, Vector2, Vector3)):
            super(TestBase, self).assertEqual(v1, v2)
        else:
            for i,j in zip(tuple(v1), tuple(v2)): super(TestBase, self).assertEqual(i, j)

    def assertAlmostEqual(self, v1, v2):
        if not isinstance(v1, (list, tuple, Vector2, Vector3)):
            super(TestBase, self).assertAlmostEqual(v1, v2)
        else:
            for i,j in zip(tuple(v1), tuple(v2)): super(TestBase, self).assertAlmostEqual(i, j)

    def assertInRange(self, value, minval, maxval):
        if not isinstance(value, (list, tuple)):
            value = (value,)
        if not isinstance(minval, (list, tuple)):
            minval = (minval,)
        if not isinstance(maxval, (list, tuple)):
            maxval = (maxval,)

        for i,j in zip(value,minval): self.assertGreaterEqual(i, j)
        for i,j in zip(value,maxval): self.assertLessEqual(i, j)

    def assertInTol(self, value, other, tol=None):
        if isinstance(value, (Vector2, Vector3)):
            value = tuple(value)
        elif not isinstance(value, (list, tuple)):
            value = (value,)

        if isinstance(other, (Vector2, Vector3)):
            other = tuple(other)
        elif not isinstance(other, (list, tuple)):
            other = (other,)

        if tol is None:
            tol = self.pw.Database.getSamePointTolerance()

        if isinstance(tol, float) and tol == 0.0:
            self.assertEqual(value, other)
        elif isinstance(tol, str) and tol.endswith("%"):
            tol = float(tol[0:-1]) / 100.0
            minval = tuple(map(lambda v: v - tol*v, other))
            maxval = tuple(map(lambda v: v + tol*v, other))
            self.assertInRange(value, minval, maxval)
        else:
            minval = tuple(map(lambda v: v - tol, other))
            maxval = tuple(map(lambda v: v + tol, other))
            self.assertInRange(value, minval, maxval)

